@@ -1,6 +1,6 @@
 package Mojolicious::Plugin::TtRenderer::Engine;
 {
-  $Mojolicious::Plugin::TtRenderer::Engine::VERSION = '1.42_02';
+  $Mojolicious::Plugin::TtRenderer::Engine::VERSION = '1.42_03';
 }
 
 use warnings;
@@ -37,7 +37,7 @@ sub _init {
     if($dir=$args{cache_dir}) {
 
       if($app && substr($dir,0,1) ne '/') {
-        $dir=$app->home->rel_dir('tmp/ctpl');
+        $dir=$app->home->rel_dir($dir);
       }
     }
 
